@@ -15,8 +15,8 @@ class Header(object):
         self.apiReqId = apiReqId
         self.awsReqId = awsReqId
         self.funcName = funcName
-
-        self.tags = "tierName={};appServerName={};appName={}".format(context.tier_name, context.server_name, funcName)
+        self.tags = "tierName={};ndAppServerHost={};appName={}".format(context.tier_name, context.server_name, funcName)
+        #self.tags = "tierName={};appServerName={};appName={}".format(context.tier_name, context.server_name, funcName)
 
         self.agentType = 0  # Python
         self.messageType = None
